clear; clc
N=2000;
disp('======================================================================');
disp('        Closed and Almost unstable loop')
disp('           x1 ->x2  x2->x3 x3->x1                   ');
disp('======================================================================');
h0=sum(100*clock)
randn('state', h0)
SZ=[1 5 .30;5 100 2;.30 2 1];SZ=chol(SZ);
wi=randn(3,N);
wi=SZ'*wi;
x1=zeros(1,N);
x2=zeros(1,N);
x3=zeros(1,N);

% Variables initialization
for t=1:2,
   x1(t)=randn(1); x2(t)=randn(1); x3(t)=randn(1);
end;

chLabels = []; % or 
%chLabels = {'x_1';'x_2';'x_3';'x_4';'x_5'};

for t=3:N,
   x1(t) = 0.95*sqrt(2)*x1(t-1) - 0.9025*x1(t-2) + 0.35*x3(t-1)+ wi(1,t);
   x2(t) = .5*x1(t-1)+.5*x2(t-1) + wi(2,t);
   x3(t) = -.5*x3(t-1) + x2(t-1)+ wi(3,t);
end;

nDiscard=40000; % number of points discarded at beginning of series (sem efeito)
nPoints=2000;   % number of analyzed samples points

y=[x1' x2' x3'];% x4' x5']; % data must be organized column-wise

u=y(N-nPoints+1:N,:);%size(u),pause

%==========================================================================
%             original PDCn estimation and analysis parameters
%==========================================================================

run example_analysis_parameters % Setting default paramaters 

run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.

%=======Overriding some default parameters for plotting and analysis=======

flgPrinting = [1 1 1 2 2 0 1]; % overriding default setting

 alpha=0.05;         % Significance level
% gct_signif = 0.05;  % Granger causality test significance level
% igct_signif = 0.05; % Instantaneous GCT significance level


% metric = 'euc';
% 
% run example_pdc_analysis
% 
% %save baccala2001a_ex5_PDC
% flgColor = 1;
% %==========================================================================
% %                        PDCn Matrix Layout Plotting
% %==========================================================================
% w_max=fs/2;
%    
% for kflgColor = flgColor,
%    h=figure;
%    set(h,'NumberTitle','off','MenuBar','figure', ...
%          'Name', 'Cap Asymp')
%    [hxlabel hylabel] = pdc_xplot_article2(c,...
%                               flgPrinting,fs,w_max,chLabels,kflgColor);
%    [ax,hT]=suplabel(['cap asymp: ' ...
%       int2str(nPoints) ' data points.'],'t');
%    set(hT,'FontSize',12); % Title font size
%    pdc_xplot_title(alpha,metric);
% end;

metric = 'info';

run example_pdc_analysis

%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;
flgColor = 1;   
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','figure', ...
         'Name', 'Figure 7.2 Oscillator with close-loop')
   [hxlabel hylabel] = pdc_xplot_article2(c,...
                              flgPrinting,fs,w_max,chLabels,kflgColor);
   [ax,hT]=suplabel(['Oscillator loop: ' ...
      int2str(nPoints) ' data points.'],'t');
   set(hT,'FontSize',12); % Title font size
   pdc_xplot_title(alpha,metric);
end;

disp('======================================================================');
disp('      This completes the Example 5 (Baccal & Sameshima, 2001)');
disp('======================================================================');
