function [res, resa] = notch_monte_carlo(m,nd,ndiscard,metric)
%Perform Monte Carlo (MC) simulation.
%
%function [res, resa] = notch_unbalanced_mc(m = 10000, nd = 20000, ndiscard = 2000)
%
% input: m - number of simulation
%        nd - data length
%        ndiscard - initial discarded points
%
% output:  res       - results used by qqplots.m
%          resa      -
if nargin == 0,
   m=2000
   nd = 2000
   ndiscard = 2000;
   metric = 'diag';
end;
global pr_

pr_.metric = metric   % Asymptotic statistics metric
pr_.fixp = 1;         % True
pr_.maxp = 3;  IP = 3;% max IP
pr_.ss = 0;           % False
pr_.nf =128;          % Number of frequency points.
                      % if vector presented at those points LAB26/11/2012
pr_.v = 0;            % False

n = 2;                % Number of variables?
if nargin < 3,
   ndiscard = 200;
end;
[Ao, eo] = model2([]);

sumA = 0;
sume = 0;

res = zeros(m,n,n,pr_.nf);
for i = 1:m,        % m simulations
   
   if mod(i,100) == 0, fprintf('iter %4.0f\n', i); end;
   
   % Generate data sample.
   data = ar_data_notch_unbalanced(Ao, eo, nd, ndiscard); % Ao & eo are truth values 
                                             % of the VAR model
   % MVAR estimation:                                          
   [du,e,A,pb,B,ef,eb,vaic,Vaicv] = mvar(data,IP,1,5);
                                    %    alg=1;       Nutall-Strand
                                    %    criterion=5; Fixed IP
                                    %    maxIP = IP;  IP value itself
   res(i,:,:,:) = abs(pdc_alg_A(A, e, pr_.nf,pr_.metric)).^2;


   sumA = sumA + A;
   sume = sume + e;

   pr_.v = 0; %False;

end;

% Average A & e
Am = sumA/m;
em = sume/m;

resa = zeros(4,n,n,pr_.nf);

data = ar_data_notch_unbalanced(Ao, eo, nd, ndiscard);
alpha = 0.05;

c = asymp_pdc(data, Am, em, pr_.nf,pr_.metric,alpha);

resa(1,:,:,:) = c.pdc;            % pdc
resa(2,:,:,:) = sqrt(c.varass1);  % r[1] == th
resa(3,:,:,:) = c.patden*nd;      % r[6] == patden
resa(4,:,:,:) = c.patdf;          % r[5] == patdf

%eval(['save notch_monte_carlo_' date])

%==========================================================================
function [A,e]= model2(dummy)
% Adapted from Baccala & Sameshima 2001
e =[100 0.5 ;0.5 1];
A = zeros(2,2,3);
A(1,1,1) = .5;
A(2,1,1) = 1;
A(2,2,1)=-.5;
A(2,1,3) = 1;

function c = ar_data_notch_unbalanced(A, er, m, ndiscard)
% function c = ar_data(A, er, m, ndiscard)
%    Simulate ar-model from A matrix
%
%       Input:
%         A(n, n, p) - AR model (n - number of signals, p - model order)
%         er(n) - variance of innovations
%         m - length of simulated time-series
%
%       Output:
%         data(n, m) - simulated time-series
% 

if ndims(A) == 2,
   [n,du]=size(A);
   p=1;
elseif ndims(A) == 3,
   [n du p] = size(A);
else
   error('A matrix dimension > 3.');
end;

N=m;
nPoints=N-ndiscard;
SZ=[100 0.5 ;0.5 1];SZ=chol(SZ);
wi=randn(2,N);
wi=SZ'*wi;
x1=zeros(1,N);
x2=zeros(1,N);


% Variables initialization
for t=1:3,
   x1(t)=randn(1); x2(t)=randn(1);%

end;

chLabels = []; % or 
%chLabels = {'x_1';'x_2';'x_3';'x_4';'x_5'};

for t=4:N,
   x1(t) = .5*x1(t-1)+ wi(1,t);
   x2(t) = -.5*x2(t-1)+x1(t-1)+x1(t-3) + wi(2,t);
end;

nDiscard=40000; % number of points discarded at beginning of series (sem efeito)
nPoints=1000;   % number of analyzed samples points

y=[x1' x2'];% x3'];% x4' x5']; % data must be organized column-wise
c=y(N-nPoints+1:N,:)';%size(u),
